==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/WebTLSConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class WebTLSConfigBuilder extends io.fabric8.openshift.api.model.monitoring.v1.WebTLSConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.WebTLSConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.WebTLSConfig,io.fabric8.openshift.api.model.monitoring.v1.WebTLSConfigBuilder>{
  public WebTLSConfigBuilder() {
    this(false);
  }
  public WebTLSConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new WebTLSConfig(), validationEnabled);
  }
  public WebTLSConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.WebTLSConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public WebTLSConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.WebTLSConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new WebTLSConfig(), validationEnabled);
  }
  public WebTLSConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.WebTLSConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.WebTLSConfig instance) {
    this(fluent, instance, false);
  }
  public WebTLSConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.WebTLSConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.WebTLSConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCert(instance.getCert()); 
    fluent.withCipherSuites(instance.getCipherSuites()); 
    fluent.withClientAuthType(instance.getClientAuthType()); 
    fluent.withClientCa(instance.getClientCa()); 
    fluent.withCurvePreferences(instance.getCurvePreferences()); 
    fluent.withKeySecret(instance.getKeySecret()); 
    fluent.withMaxVersion(instance.getMaxVersion()); 
    fluent.withMinVersion(instance.getMinVersion()); 
    fluent.withPreferServerCipherSuites(instance.getPreferServerCipherSuites()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public WebTLSConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.WebTLSConfig instance) {
    this(instance,false);
  }
  public WebTLSConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.WebTLSConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCert(instance.getCert()); 
    this.withCipherSuites(instance.getCipherSuites()); 
    this.withClientAuthType(instance.getClientAuthType()); 
    this.withClientCa(instance.getClientCa()); 
    this.withCurvePreferences(instance.getCurvePreferences()); 
    this.withKeySecret(instance.getKeySecret()); 
    this.withMaxVersion(instance.getMaxVersion()); 
    this.withMinVersion(instance.getMinVersion()); 
    this.withPreferServerCipherSuites(instance.getPreferServerCipherSuites()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.WebTLSConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.WebTLSConfig build() {
    WebTLSConfig buildable = new WebTLSConfig(fluent.getCert(),fluent.getCipherSuites(),fluent.getClientAuthType(),fluent.getClientCa(),fluent.getCurvePreferences(),fluent.getKeySecret(),fluent.getMaxVersion(),fluent.getMinVersion(),fluent.getPreferServerCipherSuites());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    WebTLSConfigBuilder that = (WebTLSConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-6.1.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/WebTLSConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class WebTLSConfigBuilder extends WebTLSConfigFluentImpl<WebTLSConfigBuilder> implements VisitableBuilder<WebTLSConfig,WebTLSConfigBuilder>{
  public WebTLSConfigBuilder() {
    this(false);
  }
  public WebTLSConfigBuilder(Boolean validationEnabled) {
    this(new WebTLSConfig(), validationEnabled);
  }
  public WebTLSConfigBuilder(WebTLSConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public WebTLSConfigBuilder(WebTLSConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new WebTLSConfig(), validationEnabled);
  }
  public WebTLSConfigBuilder(WebTLSConfigFluent<?> fluent,WebTLSConfig instance) {
    this(fluent, instance, false);
  }
  public WebTLSConfigBuilder(WebTLSConfigFluent<?> fluent,WebTLSConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCert(instance.getCert()); 
    fluent.withCipherSuites(instance.getCipherSuites()); 
    fluent.withClientAuthType(instance.getClientAuthType()); 
    fluent.withClientCa(instance.getClientCa()); 
    fluent.withCurvePreferences(instance.getCurvePreferences()); 
    fluent.withKeySecret(instance.getKeySecret()); 
    fluent.withMaxVersion(instance.getMaxVersion()); 
    fluent.withMinVersion(instance.getMinVersion()); 
    fluent.withPreferServerCipherSuites(instance.getPreferServerCipherSuites()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public WebTLSConfigBuilder(WebTLSConfig instance) {
    this(instance,false);
  }
  public WebTLSConfigBuilder(WebTLSConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withCert(instance.getCert()); 
    this.withCipherSuites(instance.getCipherSuites()); 
    this.withClientAuthType(instance.getClientAuthType()); 
    this.withClientCa(instance.getClientCa()); 
    this.withCurvePreferences(instance.getCurvePreferences()); 
    this.withKeySecret(instance.getKeySecret()); 
    this.withMaxVersion(instance.getMaxVersion()); 
    this.withMinVersion(instance.getMinVersion()); 
    this.withPreferServerCipherSuites(instance.getPreferServerCipherSuites()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  WebTLSConfigFluent<?> fluent;
  Boolean validationEnabled;
  public WebTLSConfig build() {
    WebTLSConfig buildable = new WebTLSConfig(fluent.getCert(),fluent.getCipherSuites(),fluent.getClientAuthType(),fluent.getClientCa(),fluent.getCurvePreferences(),fluent.getKeySecret(),fluent.getMaxVersion(),fluent.getMinVersion(),fluent.getPreferServerCipherSuites());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
